from dataclasses import dataclass
from datetime import datetime

@dataclass
class Timings:
    Fajr: datetime
    Sunrise: datetime
    Dhuhr: datetime
    Asr: datetime
    Sunset: datetime
    Maghrib: datetime
    Isha: datetime
    Imsak: datetime
    Midnight: datetime
    Firstthird: datetime
    Lastthird: datetime

@dataclass
class Hijri:
    Date: str
    Month: str
    Year: int

@dataclass
class Prayer:
    timings: Timings
    hijri: Hijri



from typing import Any, Dict

from adhan.models import Hijri, Timings
from datetime import datetime


def json_timings(timings: Dict[Any, Any]) -> Timings:
    t = timings
    for k, v in t.items():
        timings[k] = datetime.fromisoformat(v)

    return Timings(**t)

def json_hijri(hijri: Dict[Any, Any]) -> Hijri:
    return Hijri(
        Date = hijri['date'],
        Month = hijri['month']['en'],
        Year = int(hijri['year']),
    ) 




from typing import Optional
from adhan.const import TIMINGS_URL
from adhan.utils import json_timings, json_hijri
from .models import *
import requests

class Client:
    """Client responsible for interfacing with the API"""
    def __init__(
            self,
            latitude: Optional[float] = None,
            longitude: Optional[float] = None,
            address: Optional[str] = None,
            city: Optional[str] = None,
            country: Optional[str] = None,
            state: Optional[str] = None
            ):

        self._latitude = latitude
        self._longitude = longitude
        self._address = address
        self._city = city
        self._country = country
        self._state = state

    def get_day(self, date: Optional[str] = None) -> Prayer:
        if date:
            url = f"{TIMINGS_URL}/{date}"
        else:
            url = TIMINGS_URL
        resp = requests.get(
            url,
            {
                'latitude': self._latitude,
                'longitude': self._longitude,
                'iso8601': 'true'
            }
        ).json()
        timings = json_timings(resp['data']['timings'])
        hijri = json_hijri(resp['data']['date']['hijri'])

        return Prayer(timings, hijri)
        
